@@ -2,10 +2,10 @@ from .image_reduction import ImageReduction
 from .spectrum1D import Spectrum1D
 from .twodspec import TwoDSpec
 from .onedspec import OneDSpec
-from .wavelengthcalibration import WavelengthCalibration
-from .fluxcalibration import StandardLibrary, FluxCalibration
+from .wavelength_calibration import WavelengthCalibration
+from .flux_calibration import StandardLibrary, FluxCalibration
 
 __all__ = [
     'ImageReduction', 'Spectrum1D', 'TwoDSpec', 'OneDSpec',
-    'WavelengthCalibration', 'StandardLibrary', 'FluxCalibration'
+    'WavelengthCalibration', 'StandardLibrary', 'FluxCalibration',
 ]
