@@ -20,14 +20,14 @@ def test_full_run():
     ]
     element = ['Xe'] * len(atlas)
 
-    spatial_mask = np.arange(70, 200)
+    spatial_mask = np.arange(35, 200)
     spec_mask = np.arange(50, 1024)
 
     # Science frame
     lhs6328_frame = image_reduction.ImageReduction(
-        'test/test_data/sprat_LHS6328.list',
-        log_level='DEBUG',
-        log_file_folder='test/test_output/')
+        log_level='INFO', log_file_folder='test/test_output/')
+    lhs6328_frame.add_filelist('test/test_data/sprat_LHS6328.list')
+    lhs6328_frame.load_data()
     lhs6328_frame.reduce()
     lhs6328_frame.save_fits('test/test_output/test_full_run_standard_image',
                             overwrite=True)
@@ -37,8 +37,9 @@ def test_full_run():
         spatial_mask=spatial_mask,
         spec_mask=spec_mask,
         cosmicray=True,
+        psfmodel='gaussxy',
         readnoise=5.7,
-        log_level='DEBUG',
+        log_level='INFO',
         log_file_folder='test/test_output/')
 
     lhs6328_twodspec.ap_trace(nspec=2, display=False)
@@ -48,8 +49,7 @@ def test_full_run():
                                 skywidth=10,
                                 skydeg=1,
                                 optimal=True,
-                                display=False,
-                                save_iframe=False)
+                                display=False)
 
     # Force extraction
     lhs6328_twodspec.ap_extract(
@@ -59,8 +59,7 @@ def test_full_run():
         optimal=True,
         forced=True,
         variances=lhs6328_twodspec.spectrum_list[1].var,
-        display=False,
-        save_iframe=False)
+        display=False)
 
     # Aperture extraction
     lhs6328_twodspec.ap_extract(
@@ -69,7 +68,7 @@ def test_full_run():
         skydeg=1,
         optimal=False,
         display=False,
-        save_iframe=True,
+        save_fig=True,
         filename='test/test_output/test_full_run_extract')
 
     # Optimal extraction
@@ -81,7 +80,7 @@ def test_full_run():
         forced=True,
         variances=1000000.,
         display=False,
-        save_iframe=True,
+        save_fig=True,
         filename='test/test_output/test_full_run_extract')
 
     lhs6328_twodspec.save_fits(
@@ -89,9 +88,9 @@ def test_full_run():
 
     # Standard frame
     standard_frame = image_reduction.ImageReduction(
-        'test/test_data/sprat_Hiltner102.list',
-        log_level='DEBUG',
-        log_file_folder='test/test_output/')
+        log_level='INFO', log_file_folder='test/test_output/')
+    standard_frame.add_filelist('test/test_data/sprat_Hiltner102.list')
+    standard_frame.load_data()
     standard_frame.reduce()
     standard_frame.save_fits('test/test_output/test_full_run_standard_image',
                              overwrite=True)
@@ -99,10 +98,11 @@ def test_full_run():
     hilt102_twodspec = spectral_reduction.TwoDSpec(
         standard_frame,
         cosmicray=True,
+        psfmodel='gaussyx',
         spatial_mask=spatial_mask,
         spec_mask=spec_mask,
         readnoise=5.7,
-        log_level='DEBUG',
+        log_level='INFO',
         log_file_folder='test/test_output/')
 
     hilt102_twodspec.ap_trace(nspec=1, resample_factor=10, display=False)
@@ -112,24 +112,21 @@ def test_full_run():
                                 skywidth=5,
                                 skydeg=1,
                                 optimal=True,
-                                display=False,
-                                save_iframe=False)
-
-    # Add a 2D arc image
-    lhs6328_twodspec.add_arc(lhs6328_frame)
-    hilt102_twodspec.add_arc(standard_frame)
-
-    lhs6328_twodspec.apply_twodspec_mask_to_arc()
-    hilt102_twodspec.apply_twodspec_mask_to_arc()
+                                display=False)
 
     # Extract the 1D arc by aperture sum of the traces provided
-    lhs6328_twodspec.extract_arc_spec(display=False)
+    lhs6328_twodspec.extract_arc_spec(
+        display=False,
+        save_fig=True,
+        fig_type='jpg+png+pdf+svg+iframe',
+        filename='test/test_output/test_full_run_arc_spec',
+        return_jsonstring=True)
     hilt102_twodspec.extract_arc_spec(display=False)
+    hilt102_twodspec.create_fits(output='trace+count')
 
     # Handle 1D Science spectrum
     lhs6328_onedspec = spectral_reduction.OneDSpec(
-        log_level='DEBUG',
-        log_file_folder='test/test_output/')
+        log_level='INFO', log_file_folder='test/test_output/')
     lhs6328_onedspec.from_twodspec(lhs6328_twodspec, stype='science')
     lhs6328_onedspec.from_twodspec(hilt102_twodspec, stype='standard')
 
@@ -160,15 +157,16 @@ def test_full_run():
     lhs6328_onedspec.set_ransac_properties(filter_close=True,
                                            stype='science+standard')
 
-    lhs6328_onedspec.load_user_atlas(elements=element,
-                                     wavelengths=atlas,
-                                     stype='science+standard')
+    lhs6328_onedspec.add_user_atlas(elements=element,
+                                    wavelengths=atlas,
+                                    stype='science+standard')
     lhs6328_onedspec.do_hough_transform()
 
     # Solve for the pixel-to-wavelength solution
     lhs6328_onedspec.fit(max_tries=200,
                          stype='science+standard',
                          display=False)
+    lhs6328_onedspec.robust_refit()
 
     # Apply the wavelength calibration and display it
     lhs6328_onedspec.apply_wavelength_calibration(stype='science+standard')
@@ -176,13 +174,16 @@ def test_full_run():
     # Get the standard from the library
     lhs6328_onedspec.load_standard(target='hiltner102')
 
-    lhs6328_onedspec.compute_sensitivity(k=3,
-                                         method='interpolate',
-                                         mask_fit_size=1,
-                                         extinction_correction=True)
+    lhs6328_onedspec.get_sensitivity(k=3,
+                                     method='interpolate',
+                                     mask_fit_size=1)
 
     lhs6328_onedspec.apply_flux_calibration(stype='science+standard')
 
+    lhs6328_onedspec.get_telluric_profile()
+    lhs6328_onedspec.inspect_telluric_profile(display=False)
+    lhs6328_onedspec.apply_telluric_correction()
+
     # Apply atmospheric extinction correction
     lhs6328_onedspec.set_atmospheric_extinction(location='orm')
     lhs6328_onedspec.apply_atmospheric_extinction_correction()
@@ -238,4 +239,5 @@ def test_full_run():
     lhs6328_onedspec.inspect_reduced_spectrum(
         filename='test/test_output/test_full_run',
         display=False,
-        save_iframe=True)
+        save_fig=True,
+        fig_type='iframe+png')
